@@ -6,9 +6,9 @@
 #' @param prob Use for a two-arm design in which either floor(N_block*prob) or ceiling(N_block*prob) units are assigned to treatment within each block. The probability of assignment to treatment is exactly prob because with probability 1-prob, floor(N_block*prob) units will be assigned to treatment and with probability prob, ceiling(N_block*prob) units will be assigned to treatment. prob must be a real number between 0 and 1 inclusive. (optional)
 #' @param prob_each Use for a multi-arm design in which the values of prob_each determine the probabilities of assignment to each treatment condition. prob_each must be a numeric vector giving the probability of assignment to each condition. All entries must be nonnegative real numbers between 0 and 1 inclusive and the total must sum to 1. Because of integer issues, the exact number of units assigned to each condition may differ (slightly) from assignment to assignment, but the overall probability of assignment is exactly prob_each. (optional)
 #' @param m Use for a two-arm design in which the scalar m describes the fixed number of units to assign in each block. This number does not vary across blocks.
-#' @param block_m Use for a two-arm design in which the vector block_m describes the number of units to assign to treatment within each block. block_m must be a numeric vector that is as long as the number of blocks. Note that in previous versions of randomizr, block_m behaved like block_m_each.
+#' @param block_m Use for a two-arm design in which the vector block_m describes the number of units to assign to treatment within each block. block_m must be a numeric vector that is as long as the number of blocks and is in the same order as sort(unique(blocks)).
 #' @param block_m_each Use for a multi-arm design in which the values of block_m_each determine the number of units assigned to each condition. block_m_each must be a matrix with the same number of rows as blocks and the same number of columns as treatment arms. Cell entries are the number of units to be assigned to each treatment arm within each block. The rows should respect the ordering of the blocks as determined by sort(unique(blocks)). The columns should be in the order of conditions, if specified.
-#' @param block_prob Use for a two-arm design in which block_prob describes the probability of assignment to treatment within each block. Differs from prob in that the probability of assignment can vary across blocks.
+#' @param block_prob Use for a two-arm design in which block_prob describes the probability of assignment to treatment within each block. Must be in the same order as sort(unique(blocks)). Differs from prob in that the probability of assignment can vary across blocks. 
 #' @param block_prob_each Use for a multi-arm design in which the values of block_prob_each determine the probabilities of assignment to each treatment condition. block_prob_each must be a matrix with the same number of rows as blocks and the same number of columns as treatment arms. Cell entries are the probabilities of assignment to treatment within each block. The rows should respect the ordering of the blocks as determined by sort(unique(blocks)). Use only if the probabilities of assignment should vary by block, otherwise use prob_each. Each row of block_prob_each must sum to 1.
 #' @param num_arms The number of treatment arms. If unspecified, num_arms will be determined from the other arguments. (optional)
 #' @param conditions A character vector giving the names of the treatment groups. If unspecified, the treatment groups will be named 0 (for control) and 1 (for treatment) in a two-arm trial and T1, T2, T3, in a multi-arm trial. An exception is a two-group design in which num_arms is set to 2, in which case the condition names are T1 and T2, as in a multi-arm trial with two arms. (optional)
@@ -91,21 +91,33 @@ block_ra <- function(blocks = NULL,
   }
   
   block_spots <-
-    unlist(split(1:length(blocks), blocks), FALSE, FALSE)
+    unlist(split(seq_along(blocks), blocks), FALSE, FALSE)
   
   mapply_args <- list(
-    FUN="complete_ra",
-    SIMPLIFY=FALSE,
-    N=N_per_block,
+    FUN = "complete_ra",
+    SIMPLIFY = FALSE,
+    N = N_per_block,
     MoreArgs = list(
       conditions = conditions,
       num_arms = num_arms,
       check_inputs = FALSE
-  ))
+    )
+  )
   
-  assign_list <- block_ra_helper(blocks, prob, prob_each, m, 
-                                 block_m, block_m_each, block_prob,
-                                 block_prob_each, num_arms, N_per_block, mapply_args)
+  assign_list <-
+    block_ra_helper(
+      blocks,
+      prob,
+      prob_each,
+      m,
+      block_m,
+      block_m_each,
+      block_prob,
+      block_prob_each,
+      num_arms,
+      N_per_block,
+      mapply_args
+    )
   
   
   assignment <-
@@ -184,7 +196,7 @@ block_ra_probabilities <- function(blocks = NULL,
   }
   
   block_spots <-
-    unlist(split(1:length(blocks), blocks), FALSE, FALSE)
+    unlist(split(seq_along(blocks), blocks), FALSE, FALSE)
   
   blocks <- sort(unique(blocks))
 
@@ -199,9 +211,19 @@ block_ra_probabilities <- function(blocks = NULL,
     SIMPLIFY = FALSE
   )
 
-  prob_mat <-  block_ra_helper(blocks, prob, prob_each, m, 
-                               block_m, block_m_each, block_prob,
-                               block_prob_each, num_arms, N_per_block, mapply_args)
+  prob_mat <-  block_ra_helper(
+    blocks,
+    prob,
+    prob_each,
+    m,
+    block_m,
+    block_m_each,
+    block_prob,
+    block_prob_each,
+    num_arms,
+    N_per_block,
+    mapply_args
+  )
   
   prob_mat <- do.call(rbind, prob_mat)
   prob_mat <- prob_mat[order(block_spots), , drop = FALSE]
@@ -262,7 +284,7 @@ block_ra_helper <- function(blocks = NULL,
   
   else if (!is.null(block_m_each)) {
     block_m_each_list <-
-      split(block_m_each, rep(1:nrow(block_m_each), times = ncol(block_m_each)))
+      split(block_m_each, seq_len(nrow(block_m_each)))
     
     ret <- list(m_each=block_m_each_list)
   }
@@ -272,7 +294,7 @@ block_ra_helper <- function(blocks = NULL,
   
   else if (!is.null(block_prob_each)) {
     block_prob_each_list <-
-      split(block_prob_each, rep(1:nrow(block_prob_each), times = ncol(block_prob_each)))
+      split(block_prob_each, seq_len(nrow(block_prob_each)))
     
     ret <- list(prob_each=block_prob_each_list)
   }
